# Model
from .battery import Battery
from .cpu import Cpu
from .data import Data
from .disk import Disk
from .display import Display
from .generic import Generic
from .gpu import Gpu
from .keyboard_key import KeyboardKey
from .keyboard_text import KeyboardText
from .media import Media
from .media_directories import MediaDirectories
from .media_files import File, MediaFiles
from .memory import Memory
from .network import Network
from .notification import Notification
from .open_path import OpenPath
from .open_url import OpenUrl
from .processes import Processes
from .response import Response
from .sensors import Sensors
from .system import System

MODEL_BATTERY = "battery"
MODEL_CPU = "cpu"
MODEL_DATA = "data"
MODEL_DISK = "disk"
MODEL_DISPLAY = "display"
MODEL_GENERIC = "generic"
MODEL_GPU = "gpu"
MODEL_KEYBOARD_KEY = "keyboard_key"
MODEL_KEYBOARD_TEXT = "keyboard_text"
MODEL_MEDIA = "media"
MODEL_MEDIA_DIRECTORIES = "media_directories"
MODEL_MEDIA_FILE = "media_file"
MODEL_MEDIA_FILES = "media_files"
MODEL_MEMORY = "memory"
MODEL_NETWORK = "network"
MODEL_NOTIFICATION = "notification"
MODEL_OPEN_PATH = "open_path"
MODEL_OPEN_URL = "open_url"
MODEL_PROCESSES = "processes"
MODEL_RESPONSE = "response"
MODEL_SECRETS = "secrets"
MODEL_SENSORS = "sensors"
MODEL_SETTINGS = "settings"
MODEL_SYSTEM = "system"

MODEL_MAP = {
    MODEL_BATTERY: Battery,
    MODEL_CPU: Cpu,
    MODEL_DATA: Data,
    MODEL_DISK: Disk,
    MODEL_DISPLAY: Display,
    MODEL_GENERIC: Generic,
    MODEL_GPU: Gpu,
    MODEL_KEYBOARD_KEY: KeyboardKey,
    MODEL_KEYBOARD_TEXT: KeyboardText,
    MODEL_MEDIA_DIRECTORIES: MediaDirectories,
    MODEL_MEDIA_FILE: File,
    MODEL_MEDIA_FILES: MediaFiles,
    MODEL_MEDIA: Media,
    MODEL_MEMORY: Memory,
    MODEL_NETWORK: Network,
    MODEL_NOTIFICATION: Notification,
    MODEL_OPEN_PATH: OpenPath,
    MODEL_OPEN_URL: OpenUrl,
    MODEL_PROCESSES: Processes,
    MODEL_RESPONSE: Response,
    MODEL_SENSORS: Sensors,
    MODEL_SYSTEM: System,
}



# generated by datamodel-codegen:
#   filename:  media.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra


class Media(BaseModel):
    """
    Media Info
    """

    class Config:
        extra = Extra.allow

    album_artist: Optional[str] = None
    album_title: Optional[str] = None
    artist: Optional[str] = None
    duration: Optional[float] = None
    is_fast_forward_enabled: Optional[bool] = None
    is_next_enabled: Optional[bool] = None
    is_pause_enabled: Optional[bool] = None
    is_play_enabled: Optional[bool] = None
    is_previous_enabled: Optional[bool] = None
    is_rewind_enabled: Optional[bool] = None
    is_stop_enabled: Optional[bool] = None
    playback_rate: Optional[float] = None
    position: Optional[float] = None
    repeat: Optional[str] = None
    shuffle: Optional[bool] = None
    status: Optional[str] = None
    subtitle: Optional[str] = None
    thumbnail: Optional[str] = None
    title: Optional[str] = None
    track_number: Optional[int] = None
    type: Optional[str] = None
    updated_at: Optional[float] = None



# generated by datamodel-codegen:
#   filename:  processes.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    count: float
    processes: float


class Processes(BaseModel):
    """
    Processes
    """

    id: Optional[str] = Field(None, description="Event ID")
    count: float
    processes: list
    last_updated: Optional[LastUpdated] = Field(None, description="Last updated")



# generated by datamodel-codegen:
#   filename:  media_control.json

from __future__ import annotations

from enum import Enum
from typing import Any, Optional

from pydantic import BaseModel


class Action(Enum):
    play = "PLAY"
    pause = "PAUSE"
    stop = "STOP"
    previous = "PREVIOUS"
    next = "NEXT"
    seek = "SEEK"
    rewind = "REWIND"
    fastforward = "FASTFORWARD"
    shuffle = "SHUFFLE"
    repeat = "REPEAT"
    mute = "MUTE"
    volumedown = "VOLUMEDOWN"
    volumeup = "VOLUMEUP"


class MediaControl(BaseModel):
    """
    Media Control
    """

    action: Action
    value: Optional[Any] = None



# generated by datamodel-codegen:
#   filename:  display.json

from __future__ import annotations

from typing import Optional

from pydantic import BaseModel, Extra, Field


class LastUpdated(BaseModel):
    """
    Last updated
    """

    displays: Optional[float] = None


class Display(BaseModel):
    """
    Display
    """

    class Config:
        extra = Extra.allow

    id: Optional[str] = Field(None, description="Event ID")
    displays: Optional[list] = None
    last_updated: Optional[LastUpdated] = Field(None, description="Last updated")
